@@ -22,6 +22,7 @@ use std::{fs, io, fmt};
 mod tests;
 
 const DEFAULT_DELAY: u16 = 50;
+const DEFAULT_PREVIEW: u16 = 0;
 const DEFAULT_LOOP: bool = true;
 const DEFAULT_COLORS: ColorMod = ColorMod::None;
 const DEFAULT_UTF8: bool = false;
@@ -163,7 +164,10 @@ pub struct Header{
     pub color_mod: ColorMod,
     pub utf8: bool,
     pub datacols: u16,
-    pub audio: Option<String>
+    pub preview: u16,
+    pub audio: Option<String>,
+    pub title: Option<String>,
+    pub author: Option<String>,
 }
 
 #[derive(Debug, Clone, PartialEq)]
@@ -413,7 +417,10 @@ impl TryFrom<String> for Header{
         let mut color_mod: ColorMod = DEFAULT_COLORS;
         let mut utf8: bool = DEFAULT_UTF8;
         let mut datacols: u16 = 0; let mut d_set = false;
+        let mut preview: u16 = DEFAULT_PREVIEW;
         let mut audio: Option<String> = None;
+        let mut title: Option<String> = None;
+        let mut author: Option<String> = None;
         let rows = s.split("\n").collect::<Vec<&str>>();
         for row in rows{
             let tokens = row.split(" ").collect::<Vec<&str>>();
@@ -469,6 +476,13 @@ impl TryFrom<String> for Header{
                     };
                     d_set = true;
                 }
+                "preview" => {
+                    if tokens.len() < 2 {continue;}
+                    preview = match tokens[1].parse::<u16>(){
+                        Ok(v) => {v}
+                        Err(_) => {continue;}
+                    };
+                }
                 "audio" => {
                     if tokens.len() < 2 {continue;}
                     audio = match tokens[1]{
@@ -476,6 +490,22 @@ impl TryFrom<String> for Header{
                         a => {Some(a.to_string())}
                     };
                 }
+                "title" => {
+                    if tokens.len() < 2 {continue;}
+                    let mut s = "".to_string();
+                    for i in 1..tokens.len() {
+                        s.push_str(tokens[i])
+                    }
+                    title = Some(s);
+                }
+                "author" => {
+                    if tokens.len() < 2 {continue;}
+                    let mut s = "".to_string();
+                    for i in 1..tokens.len() {
+                        s.push_str(tokens[i])
+                    }
+                    author = Some(s);
+                }
                 _ => {}
             }
         }
@@ -484,7 +514,7 @@ impl TryFrom<String> for Header{
         if !d_set {
             datacols = color_mod.to_datacols();
         }
-        Ok(Self{width, height, delay, loop_enable, color_mod, utf8, datacols, audio})
+        Ok(Self{width, height, delay, loop_enable, color_mod, utf8, datacols, preview, audio, title, author})
     }
 }
 
@@ -518,10 +548,22 @@ impl Into<String> for Header{
             ret.push_str("\ndatacols ");
             ret.push_str(&self.datacols.to_string());
         }
+        if self.preview != DEFAULT_PREVIEW {
+            ret.push_str("\npreview ");
+            ret.push_str(&self.preview.to_string());
+        }
         if let Some(a) = self.audio {
             ret.push_str("\naudio ");
             ret.push_str(&a);
         }
+        if let Some(a) = self.title {
+            ret.push_str("\ntitle ");
+            ret.push_str(&a);
+        }
+        if let Some(a) = self.author {
+            ret.push_str("\nauthor ");
+            ret.push_str(&a);
+        }
         ret.push_str("\n\n");
         ret
     }
