@@ -169,7 +169,10 @@ mod body_from_text_test{
             color_mod: ColorMod::Full,
             utf8: false,
             datacols: 3,
-            audio: None
+            preview: DEFAULT_PREVIEW,
+            audio: None,
+            title: None,
+            author: None,
         };
         let body_reference = Body{
             frames: vec![
@@ -360,9 +363,12 @@ mod header_to_string_tests{
             color_mod: ColorMod::Full,
             utf8: true,
             datacols: 123,
-            audio: Some("1234567".to_string())
+            preview: 1,
+            audio: Some("1234567".to_string()),
+            title: None,
+            author: None,
         };
-        let s_ref = "width 1\nheight 2\ndelay 51\nloop false\ncolors full\nutf8\ndatacols 123\naudio 1234567\n\n".to_string();
+        let s_ref = "width 1\nheight 2\ndelay 51\nloop false\ncolors full\nutf8\ndatacols 123\npreview 1\naudio 1234567\n\n".to_string();
         let s: String = header.into();
         assert_eq!(s_ref, s);
     }
@@ -376,7 +382,10 @@ mod header_to_string_tests{
             color_mod: DEFAULT_COLORS,
             utf8: DEFAULT_UTF8,
             datacols: DEFAULT_COLORS.to_datacols(),
-            audio: None
+            preview: DEFAULT_PREVIEW,
+            audio: None,
+            title: None,
+            author: None,
         };
         let s_ref = "width 1\nheight 2\n\n".to_string();
         let s: String = header.into();
@@ -392,7 +401,10 @@ mod header_to_string_tests{
             color_mod: DEFAULT_COLORS,
             utf8: DEFAULT_UTF8,
             datacols: DEFAULT_COLORS.to_datacols()+1,
-            audio: None
+            preview: DEFAULT_PREVIEW,
+            audio: None,
+            title: None,
+            author: None,
         };
         let s_ref = "width 1\nheight 2\ndatacols 2\n\n".to_string();
         let s: String = header.into();
@@ -405,7 +417,7 @@ mod header_from_string_tests{
     use std::convert::{TryFrom};
     #[test]
     fn full(){
-        let s = "width 1\nheight 2\ndelay 3\nloop false\ncolors full\nutf8\ndatacols 5\naudio 12345".to_string();
+        let s = "width 1\nheight 2\ndelay 3\nloop false\ncolors full\nutf8\ndatacols 5\npreview 1\naudio 12345".to_string();
         let refernce = Header{
             width: 1,
             height: 2,
@@ -414,7 +426,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::Full,
             utf8: true,
             datacols: 5,
-            audio: Some("12345".to_string())
+            preview: 1,
+            audio: Some("12345".to_string()),
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -432,7 +447,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::None,
             utf8: false,
             datacols: 1,
-            audio: None
+            preview: 0,
+            audio: None,
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -450,7 +468,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::None,
             utf8: false,
             datacols: 1,
-            audio: None
+            preview: 0,
+            audio: None,
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -482,7 +503,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::Full,
             utf8: false,
             datacols: 3,
-            audio: None
+            preview: 0,
+            audio: None,
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -497,7 +521,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::Full,
             utf8: false,
             datacols: 0,
-            audio: None
+            preview: 0,
+            audio: None,
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -516,7 +543,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::Full,
             utf8: true,
             datacols: 5,
-            audio: Some("12345".to_string())
+            preview: 0,
+            audio: Some("12345".to_string()),
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
@@ -535,7 +565,10 @@ mod header_from_string_tests{
             color_mod: ColorMod::Full,
             utf8: true,
             datacols: 5,
-            audio: Some("12345".to_string())
+            preview: 0,
+            audio: Some("12345".to_string()),
+            title: None,
+            author: None,
         };
         match Header::try_from(s){
             Ok(result) => { assert_eq!(refernce, result); }
